<?php

namespace apexl\hashing\interfaces;

interface Hashing
{
    public static function generateRandomSalt(): string;
    public static function generateRandomHash(): string;
    public static function hashString($string, $salt): ?string;
}
